@@ -12,6 +12,10 @@ from sklearn.neighbors import KNeighborsClassifier
 from pneuro.appLogger import AppLogger
 from pneuro.file_methods import FileOperation
 
+import pathlib
+HERE = pathlib.Path(__file__).parent
+classificationTrainingLogs = HERE / "logs" / "classificationTrainingLogs.txt"
+
 
 class ClassificationModelTuner():
     """
