@@ -9,7 +9,9 @@ from sklearn.preprocessing import LabelEncoder
 from sklearn.preprocessing import MinMaxScaler
 
 from pneuro.appLogger import AppLogger
-
+import pathlib
+HERE = pathlib.Path(__file__).parent
+dataPreprocessingLogs = HERE/"logs"/"dataPreprocessingLogs.txt"
 
 class Preprocessor():
     """
