@@ -3,6 +3,9 @@ import os
 from pneuro.file_methods import FileOperation
 from pneuro.appLogger import AppLogger
 from pneuro.preProcess import Preprocessor
+import pathlib
+HERE = pathlib.Path(__file__).parent
+predictionLogs = HERE / "logs" / "predictionLogs.txt"
 
 
 class CustomException(Exception):
