@@ -11,6 +11,9 @@ import numpy as np
 import seaborn as sns
 
 from pneuro.appLogger import AppLogger
+import pathlib
+HERE = pathlib.Path(__file__).parent
+dataVisualizationLogs = HERE/"logs"/"dataVisualizationLogs.txt"
 
 
 class DataVisualization:
